<no title> — Akhdefo software documentation

`akhdefo_functions.unzip`(zipdir, dst_dir) | This program unzips all the zip products into one folder
`akhdefo_functions.copyImage_Data`([...]) | This program copy all the raster images.
`akhdefo_functions.copyUDM2_Mask_Data`([...]) | This program copy all raster masks.
`akhdefo_functions.Filter_PreProcess`([...]) | This program prepare and uses filters to balanace raster image brightness
`akhdefo_functions.Crop_to_AOI`([...]) | This program used to clip multiple raster files
`akhdefo_functions.Mosaic`([...]) | This program mosiacs raster images in geotif format as well grab dates the satellite image taken for further processing.
`akhdefo_functions.Coregistration`([...]) | This program coregisteres multiple rasters using both structural similarity index and feature matching techniqws.
`akhdefo_functions.DynamicChangeDetection`([...]) | This program calculates optical flow velocity from triplets of daily optical satellite images.
`akhdefo_functions.plot_stackNetwork`([...]) | This Program plots temporal network of triplets to be stacked for calculating Annual Mean Velocity from stacked optical images.
`akhdefo_functions.stackprep`([...]) | This program collects velocity candiate points for time-series analysis.
`akhdefo_functions.Time_Series`([...]) | This program uses candiate velocity points from stackprep function and performs linear interpolation in time-domain to calibrate stacked velocity.
`akhdefo_functions.akhdefo_ts_plot`([...]) | This program used for analysis time-series velocity profiles
`akhdefo_functions.rasterClip`(rasterpath, ...) | This program used to clip single raster file.
`akhdefo_functions.akhdefo_viewer`([...]) | This program used for plotting raster products.
`akhdefo_functions.Akhdefo_resample`([...]) | This program performs raster resampling for rasters
`akhdefo_functions.Akhdefo_inversion`([...]) | This program calculates 3D displacement velocity (East-West,North-South and vertical) using combined optical and InSAR products
`akhdefo_functions.utm_to_latlon`(easting, ...) | This program converts geographic projection of shapefiles from UTM to LATLONG
`akhdefo_functions.MeanProducts_plot_ts`([...]) | This program used to plot shapefile data
`akhdefo_functions.Auto_Variogram`([...]) | This program automatically selects best variogram model which later can be used to interpolate datapoints.